@@ -1,8 +1,5 @@
 from setuptools import setup, Extension
 from Cython.Build import cythonize
-from Cython.Distutils import build_ext
-from numpy.distutils.misc_util import Configuration, get_numpy_include_dirs
-import numpy
 
 extensions = [
     Extension("compute_pvalues", 
