@@ -1,4 +1,5 @@
 import networkx as nx
+import os
 from collections import defaultdict
 from scipy.stats import chi2
 import numpy as np
@@ -7,9 +8,10 @@ from functools import reduce
 
 from .DOMINO.src.core import domino
 from .DOMINO.src.core import preprocess_slices as sl
-from .DataSet import DataSet
 from .clustering import clustering
 
+dir_path = os.path.dirname(os.path.realpath(__file__))
+
 def _combine_pvals(pvals):
         chisqprob = lambda chisq, df: chi2.sf(chisq, df)
         s = -2 * np.sum(np.log(pvals))
@@ -43,7 +45,7 @@ def _affected_domains(targets, ascov):
   
             
             
-def run_domain_domino(target, is_results, name=None, scores = None, network_file = "data/network/network_human_PPIDDI.tab", output_file_path = "./slices/slices.txt", 
+def run_domain_domino(target, is_results, name=None, scores = None, network_file = os.path.join(dir_path,"data/network/network_human_PPIDDI.tab"), output_file_path = "slices.txt", 
                 run_cluster=None, slice_threshold=0.3, module_threshold=0.05, prize_factor = 0, n_steps=20):
     '''
     Parameters
@@ -128,9 +130,6 @@ def run_domain_domino(target, is_results, name=None, scores = None, network_file
 
         a=defaultdict(list)
         for u,v in target.genelist_clusters.items():
-            
-
-            
             #scoresdf.to_csv("/nfs/home/students/chit/lrz_ticone/domino_emp/{}_cluster{}_mod.csv".format(name, u), index=False)
             ### 
             checkedtarget = _check_nodes(list(map(str,v)), network_file)
@@ -163,11 +162,7 @@ def run_domain_domino(target, is_results, name=None, scores = None, network_file
         print("-----END-----")        
         return a 
 
-
-    
-
-
-def run_domino(target, name=None, is_results=None, scores = None, network_file = "data/network/mouse_biogrid_entrez.tab", output_file_path = "./slices/slices.txt", 
+def run_domino(target, name=None, is_results=None, scores = None, network_file = os.path.join(dir_path,"data/network/mouse_biogrid_entrez.tab"), output_file_path = "./slices/slices.txt", 
                 run_cluster=None, slice_threshold=0.3, module_threshold=0.05, prize_factor = 0, n_steps=20):
     '''
     Parameters
